@@ -1,37 +1,39 @@
 import os
-import sys
 
 from zope.app.pagetemplate.viewpagetemplatefile import ViewMapper
 
 from Acquisition import aq_get
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-
 from AccessControl import getSecurityManager
-
 from Products.PageTemplates.Expressions import SecureModuleImporter
 
 from z3c.pt import pagetemplate
-from five.pt.expressions import path_translator
 
 def get_physical_root(context):
     method = aq_get(context, 'getPhysicalRoot', None)
     if method is not None:
         return method()
 
+def test(condition, a, b):
+    if condition:
+        return a
+    return b
+
 class BaseTemplate(pagetemplate.BaseTemplate):
     """Zope 2-compatible page template class."""
-    
-    utility_builtins = {}
 
-    def render_macro(self, macro, global_scope=False, parameters=None):
+    utility_builtins = {}
+    encoding = 'utf-8'
+    
+    def render_macro(self, macro, parameters=None, **kw):
         context = self._pt_get_context(None, None)
 
         if parameters is not None:
             context.update(parameters)
 
         return super(BaseTemplate, self).render_macro(
-            macro, global_scope=global_scope, parameters=context)
+            macro, parameters=context, **kw)
 
     def _pt_get_context(self, instance, request, kwargs={}):
         if instance is None:
@@ -45,6 +47,7 @@ class BaseTemplate(pagetemplate.BaseTemplate):
                 here=context,
                 container=context,
                 nothing=None,
+                test=test,
                 path=pagetemplate.evaluate_path,
                 exists=pagetemplate.evaluate_exists,
                 root=get_physical_root(context),
@@ -61,12 +64,23 @@ class BaseTemplateFile(BaseTemplate, pagetemplate.BaseTemplateFile):
     """Zope 2-compatible page template file class."""
 
 class ViewPageTemplate(pagetemplate.ViewPageTemplate):
+
     def _pt_get_context(self, view, request, kwargs):
         if view is None:
             namespace = {}
         else:
-            context = aq_inner(view.context)
-            request = request or view.request
+            try:
+                request = request or view.request
+                context = aq_inner(view.context)
+            except AttributeError:
+                """This may happen with certain dynamically created
+                classes,
+                e.g. ``plone.app.form._named.GeneratedClass``.
+                """
+                view = view.context
+                request = view.request
+                context = aq_inner(view.context)
+                
             namespace = dict(
                 context=context,
                 request=request,
